<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" 
    xmlns:hl7="urn:hl7-org:v3" 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
    xmlns:xhtml="http://www.w3.org/1999/xhtml" 
    xmlns="http://www.w3.org/1999/xhtml" 
    exclude-result-prefixes="xd hl7 xsi xhtml" 
    version="1.0">
        
    <xsl:template match="/">
        <xsl:apply-templates select="/hl7:ClinicalDocument"/>
    </xsl:template>
    
    <xsl:template match="hl7:ClinicalDocument[not(ancestor::hl7:ClinicalDocument)]">
        <html xmlns="http://www.w3.org/1999/xhtml" >
            <xsl:call-template name="printHead" />
                
            <body>
                <div style="background-color:#ffffaa; width:800px" >
                <table >
                    <tr >
                        <td  width="450px">
                            <xsl:call-template name="printPatient" />
                                                        
                        </td>
                        <td valign="top">
                            <table width="100%">
                                <tr><td colspan="2" ><h1>Arbeitsunfähigkeits-</h1></td><td align="right"><h1>1</h1></td></tr>
                                <tr><td colspan="2" ><h1>bescheinigung</h1></td><td></td></tr>
                                <tr>
                                    <td  class="in-red"><h1>
                                        <xsl:choose>
                                            <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xERST'">
                                                <xsl:text>&#x2612;</xsl:text>
                                            </xsl:when>
                                            <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xERST_END'">
                                                <xsl:text>&#x2612;</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                                        </xsl:choose></h1>
                                    </td>
                                    <td  class="in-red"><h3>Erstbescheinigung</h3></td><td></td>
                                </tr>
                                <tr>
                                    <td  class="in-red"><h1>
                                        <xsl:choose>
                                            <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xFOLGE'">
                                                <xsl:text>&#x2612;</xsl:text>
                                            </xsl:when>
                                            <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xFOLGE_END'">
                                                <xsl:text>&#x2612;</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                                        </xsl:choose>  </h1>                                      
                                    </td>
                                    <td  class="in-red"><h3>Folgebescheinigung</h3></td>
                                    <td></td>
                                </tr>
                            </table>
                            <xsl:call-template name="printBarcode" />
                        </td>
                    </tr>
                </table>
                <table >
                    <colgroup>
                        <col width="450px"></col>
                        <col width="400px"></col>
                    </colgroup>
                    <tr width="60%">
                        <td>
                            <table>
                                <colgroup>
                                    <col width="40px"></col>
                                    <col width="220px"></col>
                                    <col width="40px"></col>
                                    <col width="170px"></col>
                                </colgroup>
                                <tr>
                                    <td class="in-red">
                                        <font size="+3">
                                            <xsl:choose>
                                                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'WORK-ACCIDENT'">
                                                    <xsl:text>&#x2612;</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:text>&#x2610;</xsl:text>
                                                </xsl:otherwise>
                                            </xsl:choose></font>
                                    </td>
                                    <td class="in-red">
                                        Arbeitsunfall, Arbeitsunfall- <br/>folgen, Berufskrankheit
                                    </td>
                                    <td class="in-red">
                                        <font size="+3">
                                            <xsl:choose>
                                                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'D-ARZT'">
                                                    <xsl:text>&#x2612;</xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:text>&#x2610;</xsl:text>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </font>
                                    </td>
                                    <td class="in-red">
                                        dem Durchgangsarzt<br/> zugewiesen
                                    </td>
                                </tr>
                                <tr>
                                    <td class="in-red" colspan="2">arbeitsunfähig seit  </td>
                                    <td colspan="2"> 
                                        <div align="center" style="border:1px solid black; background-color:white;" >
                                            <xsl:call-template name="formatDate">
                                                <xsl:with-param name="date" select="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='X-IATWRK']/hl7:effectiveTime/hl7:low/@value"/>
                                            </xsl:call-template>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td class="in-red" colspan="2">voraussichtlich arbeitunfähig <br/>bis einschließlich oder letzter <br/>Tag der Arbeitsfähigkeit</td>
                                    <td colspan="2"> 
                                        <div align="center" style="border:1px solid black; background-color:white;" >
                                            <xsl:call-template name="formatDate">
                                                <xsl:with-param name="date" select="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='X-IATWRK']/hl7:effectiveTime/hl7:high/@value"/>
                                            </xsl:call-template>
                                        </div>
                                    </td>
                                </tr>
                                <tr>
                                    <td class="in-red" colspan="2">festgestellt am</td>
                                    <td colspan="2">
                                        <div align="center" style="border:1px solid black; background-color:white;" >
                                            <xsl:call-template name="formatDate">
                                                <xsl:with-param name="date" select="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='X-IATWRK']/hl7:performer/hl7:time/@value"/>
                                            </xsl:call-template>
                                        </div>
                                    </td>
                                </tr>
                            </table>
                           
                            <div align="center" style="height:40px; width:450px; border:1px solid red;"><h3>Ausfertigung zur Vorlage bei der Krankenkasse</h3></div>
                        </td>
                        <td>
                            <xsl:call-template name="printArzt" />
                        </td>
                    </tr>
                </table>
                <hr color="red"/>
                <xsl:call-template name="printDiagnosen" />
                <table width="780px" bgcolor="#ffbbbb" style="border:1px solid red;">
                    <tr>
                        <td><h2>Im Krankengeldfall</h2></td>
                        <td><font color="red" size="+3">
                            <xsl:choose>
                                <!-- wenn dieses Element vorkommt, dann istddas Häkchen zusetzen -->
                                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation/hl7:code[@code='X-IATWRK']/hl7:qualifier/hl7:value/@code = 'x7AU'">
                                        <xsl:text>&#x2612;</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>&#x2610;</xsl:otherwise>
                            </xsl:choose>
                            </font>
                        </td>
                        <td class="in-red" >ab 7. AU-Woche oder <br/>sonstiger Krankengeldfall</td>
                        <td>
                            <font color="red" size="+3">
                            <xsl:choose>
                                <xsl:when test="hl7:documentationOf/hl7:ServiceEvent/hl7:code/@code = 'xERST_END'">
                                    <xsl:text>&#x2612;</xsl:text>
                                </xsl:when>
                                <xsl:when test="hl7:documentationOf/hl7:ServiceEvent/hl7:code/@code = 'xFOLGE_END'">
                                    <xsl:text>&#x2612;</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>&#x2610;</xsl:otherwise>
                            </xsl:choose>
                            </font>
                        </td>
                        <td class="in-red" >
                            Endbescheinigung
                        </td>
                    </tr>
                </table>
                    <br/>
                    <br/>
                </div>
                <!-- hier kommen jetzt alle versteckten Felder, damit diese für den Barcode verwendet werden können -->
                <xsl:call-template name="printHiddenFields"/>

            </body>
        </html>
    </xsl:template>

    <xsl:template name="printHead">
        <head>
            <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
            <title>
                Arbeitsunfähigkeitsbescheinigung
            </title>
            <script src="bcmath-min.js" type="text/javascript"></script>
            <script src="pdf417-min.js" type="text/javascript"></script>	    
            <script src="muster01.js" type="text/javascript"></script>	    
            
            <style type="text/css" media="all">
                h1 {
                font-size: 16pt;
                color: #ff0000;
                font-weight: bold;
                font-family: Verdana;
                }
                h2 {
                font-size: 14pt;
                color: #ff0000;
                font-weight: bold;
                font-family: Verdana;
                }
                h3 {
                font-size: 12pt;
                color: #ff0000;
                font-weight: bold;
                font-family: Verdana;
                }
                h4 {
                font-size: 8pt;
                color: #ff0000;
                font-weight: normal;
                font-family: Verdana;
                }
                p {
                font-gamily: "Courier";
                font-size: small;
                }
                
                .in-red {
                font-size: 10pt;
                color: #ff0000;
                font-weight: normal;
                font-family: Verdana;
                }
                
                .daten {
                font-family: "Courier New";
                }
                
                .hidden {
                display: none;
                }
            </style>
 
        </head>
    </xsl:template>
    
    <xsl:template name="printPatient">
        <table style="border:1px solid red;" bgcolor="white" >
            <colgroup>
                <col width="270px"></col>
                <col width="270px"></col>
                <col width="60px"></col>
                <col width="160px"></col>
                <col width="40px"></col>
            </colgroup>
            <tr >
                <td class="in-red" colspan="5">Krankenkasse bzw. Kostenträger</td>
            </tr>
            <tr >
                <td colspan="4" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:performer/hl7:assignedEntity/hl7:representedOrganization"/>
                </td>
                <td style="border-bottom:1px solid red;" align="right" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:entryRelationship/hl7:observation[hl7:code/@code='KV-Zuordnung']/hl7:value/@code"/>
                </td>
            </tr>
            <tr >
                <td class="in-red" colspan="5" >Name, Vorname des Versicherten</td>
            </tr>
            <tr >
                <td colspan="3" class="daten" >
                    <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:family"/>
                </td>
                <td colspan="2" ><div class="in-red">geb. am</div>
                </td>
            </tr>
            <tr >
                <td colspan="2" class="daten" >
                    <xsl:if test="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:prefix[@qualifier='AC']">
                        <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:prefix[@qualifier='AC']"/>
                        <xsl:text> </xsl:text>
                    </xsl:if>
                    <xsl:if test="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:prefix[@qualifier='NB']">
                        <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:prefix[@qualifier='NB']"/>
                        <xsl:text> </xsl:text>
                    </xsl:if>
                    <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:given"/>
                    <xsl:if test="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:prefix[@qualifier='VV']">
                        <xsl:text> </xsl:text>
                        <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:name/hl7:prefix[@qualifier='VV']"/>
                    </xsl:if>
                </td>
                <td colspan="3" class="daten">
                    <xsl:call-template name="formatDate">
                        <xsl:with-param name="date" select="hl7:recordTarget/hl7:patientRole/hl7:patient/hl7:birthTime/@value"/>
                    </xsl:call-template>
                </td>
            </tr>
            <tr >
                <td colspan="5" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:addr/hl7:streetName"/><xsl:text> </xsl:text><xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:addr/hl7:houseNumber"/><br/>
                    <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:addr/hl7:country"/><xsl:text> </xsl:text>
                    <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:addr/hl7:postalCode"/><xsl:text> </xsl:text>
                    <xsl:value-of select="hl7:recordTarget/hl7:patientRole/hl7:addr/hl7:city"/>
                </td>
            </tr>
            <tr>
                <td class="in-red" >Kostenträgerkennung</td>
                <td class="in-red" colspan="2">Versichertennummer</td>
                <td class="in-red" >Status</td>
            </tr>
            <tr>
                <td id="feld05" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:performer/hl7:assignedEntity/hl7:id/@extension"/>
                </td>
                <td id="feld06" colspan="2" style="border-left:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:participant/hl7:participantRole/hl7:id/@extension"/>
                </td>
                <td colspan="2" style="border-left:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:participant/hl7:participantRole/hl7:code/@code"/>  <xsl:text> </xsl:text>
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:entryRelationship/hl7:observation[hl7:code/@code='PRSNGRP']/hl7:value/@code"/> <xsl:text> </xsl:text>
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-6']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:entryRelationship/hl7:observation[hl7:code/@code='DMP']/hl7:value/@code"/>
                </td>
            </tr>
            <tr >
                <td class="in-red"  style="border-top:1px solid red;">Betriebsstättennummer</td>
                <td class="in-red" style="border-top:1px solid red;">Arzt-Nr</td>
                <td class="in-red" style="border-top:1px solid red;" colspan="3">Datum</td>
            </tr>
            <tr >
                <td class="daten" >
                    <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:id[@root='1.2.276.0.76.4.17']/@extension"/>
                </td>
                <td style="border-left:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:id/@extension"/>
                </td>
                <td colspan="3" style="border-left:1px solid red;" class="daten" >
                    <xsl:call-template name="formatDate">
                        <xsl:with-param name="date" select="hl7:effectiveTime/@value"/>
                    </xsl:call-template>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template name="printArzt">
        <div style="background-color:white; width:300px; border:1px solid red;" class="daten" >
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:id[@root='1.2.276.0.76.4.17']/@extension"/>&#160;&#160;&#160;
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:id[@root='1.2.276.0.76.4.16']/@extension"/>&#160;&#160;
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:id[@root='1.2.276.0.76.4.xxxxx']/@extension"/>
            <br/>
            <br/>
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:assignedPerson/hl7:name"/>
            <br/>
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:name"/>
            <br/>
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr/hl7:streetName"/>&#160;
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr/hl7:houseNumber"/>
            <br/>
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr/hl7:postalCode"/>&#160;
            <xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr/hl7:city"/>
            <br/>
            <br/>
            <font class="in-red" size="-2">Vertragsarztstempel / Unterschrift</font>
        </div>
    </xsl:template>
        
    <xsl:template name="printBarcode">
        <div id="barcode" align="center" width="100%"></div>
    </xsl:template>
    
    <xsl:template name="printDiagnosen">
        <h2>AU-begründende Diagnose(n) <font size='-1'>(ICD-10)</font></h2>
        <table>
            <tr>
                <td class="in-red" width="150px">ICD-10 - Code</td>
                <td width="30px"></td>
                <td class="in-red" width="150px">ICD-10 - Code</td>
                <td width="30px"></td>
                <td class="in-red" width="150px">ICD-10 - Code</td>
            </tr>
            <tr>
                <td bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[1]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/> &#160;
                </td>
                <td></td>
                <td bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[2]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
                </td>
                <td></td>
                <td bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[3]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
                </td>
            </tr>
            <tr>
                <td class="in-red" >ICD-10 - Code</td>
                <td></td>
                <td class="in-red" >ICD-10 - Code</td>
                <td></td>
                <td class="in-red" >ICD-10 - Code</td>
            </tr>
            <tr>
                <td bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[4]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/> &#160;
                </td>
                <td></td>
                <td bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[5]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
                </td>
                <td></td>
                <td bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[6]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
                </td>
            </tr>
            <tr>
                <td>&#160;</td>
            </tr>
            <tr>
                <td colspan="5" bgcolor="white" style="border-bottom:1px solid red;" class="daten" >
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:text"/>
                </td>
            </tr>
        </table>
        <table width="780px">
            <colgroup>
                <col width="20px"></col>
                <col width="120px"></col>
                <col width="110px"></col>
                <col width="100px"></col>
                <col width="10px"></col>
                <col width="300px"></col>
                <col width="200px"></col>
            </colgroup>
            <tr>
                <td>
                    <font color="red" size="+3">
                        <xsl:choose>
                            <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'WORK-ACCIDENT'">
                                <xsl:text>&#x2612;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                        </xsl:choose>
                    </font>
                </td>
                <td colspan="2" class="in-red" >sonstiger Unfall, <br/>Unfallfolgen</td>
                <td></td>
                <td>
                    <font color="red" size="+3">
                        <xsl:choose>
                            <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'VERSORGUNG'">
                                <xsl:text>&#x2612;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                        </xsl:choose>
                    </font>
                </td>
                <td class="in-red" >Versorgungsleiden<br/>(z.B. BVG)</td>
                <td></td>
            </tr>
            <tr>
                <td colspan="6" class="in-red">Es wird die Einleitung folgender besonderer Maßnahmen für erforderlich gehalten</td>
            </tr>
            <tr>
                <td>
                    <font color="red" size="+3">
                        <xsl:choose>
                            <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:entry/hl7:observation[hl7:code/@code='REHA']/hl7:value/@value = 'true'">
                                <xsl:text>&#x2612;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                        </xsl:choose>
                    </font>
                </td>
                <td colspan="2" class="in-red" >Leistungen zur <br/>medizinischen Rehabilitation</td>
                <td></td>
                <td>
                    <font color="red" size="+3">
                        <xsl:choose>
                            <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:entry/hl7:observation[hl7:code/@code='EINGLIEDERUNG']/hl7:value/@value = 'true'">
                                <xsl:text>&#x2612;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                        </xsl:choose>
                    </font >
                </td>
                <td class="in-red" >stufenweise<br/> Wiedereingliederung</td>
                <td></td>
            </tr>
            <tr>
                <td >
                    <font color="red" size="+3">
                        <xsl:choose>
                            <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:text != ''">
                                <xsl:text>&#x2612;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>&#x2610;</xsl:otherwise>
                        </xsl:choose>
                    </font>
                </td>
                <td class="in-red" >Sonstige</td>
                <td colspan="5" bgcolor="white" style="border-bottom:1px solid black;" class="daten" >
                    <!-- #11 -->
                    <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:text" />
                </td>
            </tr>
        </table>
    </xsl:template>
    
    <xsl:template name="formatDate">
        <xsl:param name="date"/>
        <xsl:variable name="yearNum" select="substring ($date, 1, 4)"/>
        <xsl:variable name="monthNum" select="substring ($date, 5, 2)"/>
        <xsl:variable name="dayNum" select="substring ($date, 7, 2)"/>

        <xsl:value-of select="$dayNum"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="$monthNum"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="$yearNum"/>
        
    </xsl:template>

    <xsl:template name="formatDateJJJJMMTT">
        <xsl:param name="date"/>
        <xsl:variable name="yearNum" select="substring ($date, 1, 4)"/>
        <xsl:variable name="monthNum" select="substring ($date, 5, 2)"/>
        <xsl:variable name="dayNum" select="substring ($date, 7, 2)"/>
        
        <xsl:value-of select="$yearNum"/>
        <xsl:value-of select="$monthNum"/>
        <xsl:value-of select="$dayNum"/>
        
    </xsl:template>
    
    <xsl:template name="printHiddenFields">
        <!-- hier kommen jetzt alle versteckten Felder, damit diese für den Barcode verwendet werden können -->
        <div class="hidden" id="feld04"><xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-0']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:particpant/hl7:time/hl7:high/@value"/></div>
        <div class="hidden" id="feld07"><xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-0']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:particpant/participantRole/code/@code"/></div>
        <div class="hidden" id="feld08"><xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-0']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:entryRelationship/hl7:observation[hl7:code/@code='PRSNGRP']/hl7:value/@code"/></div>
        <div class="hidden" id="feld09"><xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='48768-0']/hl7:entry/hl7:act/hl7:entryRelationship/hl7:act/hl7:entryRelationship/hl7:observation[hl7:code/@code='DMP']/hl7:value/@code"/></div>
        <div class="hidden" id="feld10"><xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:id[@root='1.2.276.0.76.4.17']/@extension"/></div>
        <div class="hidden" id="feld11"><xsl:value-of select="hl7:author/hl7:assignedAuthor/hl7:id[@root='1.2.276.0.76.4.16']/@extension"/></div>
        <div class="hidden" id="feld12">
            <xsl:call-template name="formatDateJJJJMMTT">
                <xsl:with-param name="date" select="hl7:effectiveTime/@value"/>
            </xsl:call-template>
        </div>
        <div class="hidden" id="feld13">
            <xsl:choose>
                <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xERST'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
                <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xERST_END'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
                <xsl:otherwise>&#x2610;</xsl:otherwise>
            </xsl:choose>                                      
        </div>
        <div class="hidden" id="feld14">
            <xsl:choose>
                <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xFOLGE'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
                <xsl:when test="hl7:documentationOf/hl7:serviceEvent/hl7:code/@code = 'xFOLGE_END'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
                <xsl:otherwise>&#x2610;</xsl:otherwise>
            </xsl:choose>                                      
        </div>
        <div class="hidden" id="feld15">
            <xsl:choose>
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'WORK-ACCIDENT'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld16">
            <xsl:choose>
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'D-ARZT'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld17" >
            <xsl:call-template name="formatDateJJJJMMTT">
                <xsl:with-param name="date" select="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='X-IATWRK']/hl7:effectiveTime/hl7:low/@value"/>
            </xsl:call-template>
        </div>
        <div class="hidden" id="feld18" >
            <xsl:call-template name="formatDateJJJJMMTT">
                <xsl:with-param name="date" select="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='X-IATWRK']/hl7:effectiveTime/hl7:high/@value"/>
            </xsl:call-template>
        </div>
        <div class="hidden" id="feld19">
            <xsl:call-template name="formatDateJJJJMMTT">
                <xsl:with-param name="date" select="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='X-IATWRK']/hl7:performer/hl7:time/@value"/>
            </xsl:call-template>
        </div>
        <div class="hidden" id="feld20">
            <xsl:choose>
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'WORK-ACCIDENT'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld21">
            <xsl:choose>
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation[hl7:code/@code='ACCIDENT']/hl7:value/@code = 'VERSORGUNG'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld22">
            <xsl:choose>
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:entry/hl7:observation[hl7:code/@code='REHA']/hl7:value/@value = 'true'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld23">
            <xsl:choose>
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:entry/hl7:observation[hl7:code/@code='EINGLIEDERUNG']/hl7:value/@value = 'true'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld24">
            <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='TREATMENT']/hl7:text" />
        </div>
        <div class="hidden" id="feld25">
            <xsl:choose>
                <!-- wenn dieses Element vorkommt, dann istddas Häkchen zusetzen -->
                <xsl:when test="hl7:component/hl7:structuredBody/hl7:component/hl7:section/hl7:entry/hl7:observation/hl7:code[@code='X-IATWRK']/hl7:qualifier/hl7:value/@code = 'x7AU'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld26">
            <xsl:choose>
                <xsl:when test="hl7:documentationOf/hl7:ServiceEvent/hl7:code/@code = 'xERST_END'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
                <xsl:when test="hl7:documentationOf/hl7:ServiceEvent/hl7:code/@code = 'xFOLGE_END'">
                    <xsl:text>1</xsl:text>
                </xsl:when>
            </xsl:choose>
        </div>
        <div class="hidden" id="feld27">
            <xsl:if test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[1]/hl7:entryRelationship/hl7:observation/hl7:code/@code">
                <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[1]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
            </xsl:if>
            <xsl:if test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[2]/hl7:entryRelationship/hl7:observation/hl7:code/@code">
                <xsl:text>,</xsl:text>
                <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[2]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
            </xsl:if>
            <xsl:if test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[3]/hl7:entryRelationship/hl7:observation/hl7:code/@code">
                <xsl:text>,</xsl:text>
                <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[3]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
            </xsl:if>
            <xsl:if test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[4]/hl7:entryRelationship/hl7:observation/hl7:code/@code">
                <xsl:text>,</xsl:text>
                <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[4]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
            </xsl:if>
            <xsl:if test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[5]/hl7:entryRelationship/hl7:observation/hl7:code/@code">
                <xsl:text>,</xsl:text>
                <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[5]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
            </xsl:if>
            <xsl:if test="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[6]/hl7:entryRelationship/hl7:observation/hl7:code/@code">
                <xsl:text>,</xsl:text>
                <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:entry[6]/hl7:entryRelationship/hl7:observation/hl7:code/@code"/>
            </xsl:if>
        </div>
        <div class="hidden" id="feld28">
            <xsl:value-of select="hl7:component/hl7:structuredBody/hl7:component/hl7:section[hl7:code/@code='AU-DIAGNOSIS']/hl7:text"/>
        </div>        
    </xsl:template>

</xsl:stylesheet>